==> dualword-rt_0.2.5.orig.tar.gz: dualword-rt-0.2.5/tr/tr_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>MainWindow</name>
    <message>
        <source>Toggle Full Screen</source>
        <translation>Vollbild umschalten</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Über</translation>
    </message>
    <message>
        <source>Press P or Q to start...</source>
        <translation>Drücken Sie die Taste P oder Q, um zu starten...</translation>
    </message>
    <message>
        <source>Press 2 buttons (P and Q) when you see a yellow circle...</source>
        <translation>Drücken Sie 2 Tasten (P und Q), wenn Sie einen gelben Kreis sehen...</translation>
    </message>
    <message>
        <source>Reaction time: Left hand = </source>
        <translation>Reaktionszeit: Linke Hand = </translation>
    </message>
    <message>
        <source>Right hand = </source>
        <translation>Rechte Hand = </translation>
    </message>
    <message>
        <source>               Press P or Q to continue.
</source>
        <translation>               Drücken Sie die Taste P oder Q, um fortzusetzen.
</translation>
    </message>
    <message>
        <source>Attempts:</source>
        <translation> Versuche:</translation>
    </message>
    <message>
        <source> Min:</source>
        <translation> Min:</translation>
    </message>
    <message>
        <source> Max:</source>
        <translation> Max:</translation>
    </message>
    <message>
        <source> Average:</source>
        <translation> Average:</translation>
    </message>
    <message>
        <source> (L/R)</source>
        <translation> (L/R)</translation>
    </message>
    <message>
        <source>Error.
Press P or Q to continue...</source>
        <translation>Fehler.
Drücken Sie die Taste P oder Q, um fortzusetzen...</translation>
    </message>
    <message>
        <source>Languages</source>
        <translation>Sprachen</translation>
    </message>
</context>
</TS>

==> dualword-rt_0.3.1.orig.tar.gz: dualword-rt-0.3.1/tr/tr_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>MainWindow</name>
    <message>
        <source>Toggle Full Screen</source>
        <translation>Vollbild umschalten</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Über</translation>
    </message>
    <message>
        <source>Press P or Q to start...</source>
        <translation>Drücken Sie die Taste P oder Q, um zu starten...</translation>
    </message>
    <message>
        <source>Press 2 buttons (P and Q) when you see a yellow circle...</source>
        <translation>Drücken Sie 2 Tasten (P und Q), wenn Sie einen gelben Kreis sehen...</translation>
    </message>
    <message>
        <source>Reaction time: Left hand = </source>
        <translation>Reaktionszeit: Linke Hand = </translation>
    </message>
    <message>
        <source>Right hand = </source>
        <translation>Rechte Hand = </translation>
    </message>
    <message>
        <source>               Press P or Q to continue.
</source>
        <translation>               Drücken Sie die Taste P oder Q, um fortzusetzen.
</translation>
    </message>
    <message>
        <source>Attempts:</source>
        <translation> Versuche:</translation>
    </message>
    <message>
        <source> Min:</source>
        <translation> Min:</translation>
    </message>
    <message>
        <source> Max:</source>
        <translation> Max:</translation>
    </message>
    <message>
        <source> Average:</source>
        <translation> Average:</translation>
    </message>
    <message>
        <source> (L/R)</source>
        <translation> (L/R)</translation>
    </message>
    <message>
        <source>Error.
Press P or Q to continue...</source>
        <translation>Fehler.
Drücken Sie die Taste P oder Q, um fortzusetzen...</translation>
    </message>
    <message>
        <source>Languages</source>
        <translation>Sprachen</translation>
    </message>
    <message>
        <source>New language will be available after a restart.</source>
        <translation>Die neue Sprache wird nach einem Neustart verfügbar sein.</translation>
    </message>
</context>
</TS>
